<?php
/*
Plugin Name: Last user login
Plugin URI: https://www.htmlcss.fr
Description: Permet d'afficher les dates des dernières connexions des utilisateurs sur le tableau de bord.
Author: François Riant
Version: 0.1
Author URI: https://www.htmlcss.fr
*/


//Capture la date de connexion de l'utilisateur et l'enregistre au format timestamp dans une nouvelle donnée meta.
add_action( 'wp_login', 'lul_savedate');
function lul_savedate( $user_login, $user )
{
    update_user_meta( $user->ID, 'lul_last_login', time() );
}

// ajoute un widget sur le dashbord
add_action('wp_dashboard_setup', 'lul_add_widget');
function lul_add_widget()
{
    wp_add_dashboard_widget('lul_widget_user_info', 'Dernière connexion des utilisateurs','lul_render_widget');
}

// affiche le widget sur le dashbord
function lul_render_widget()
{
  $args = [
      'role__in' => ['administrator', 'editor', 'author', 'contributor', 'subscriber'],
      'orderby' => 'login',
      'order' => 'ASC',
  ];
  $user_list = get_users($args);
  ?>
    <table class="lul_user_table" cellspacing="0">
    <thead>
        <tr>
            <td width="33.3333%"><strong>Utilisateur</strong></td>
            <td width="33.3333%"><strong>Rôle</strong></td>
            <td width="33.3333%"><strong>Dernière connexion</strong></td>
        </tr>
        <thead>
        <tbody>
            <?php
                foreach ($user_list as $key => $user) :
                    $user_id = $user->data->ID;
                    $user_name = $user->data->display_name;
                    $user_role = $user->roles;
                    $last_date = lul_get_user_last_login($user_id);
            ?>
            <tr>
                <td width="33.3333%"><?= $user_name ?></td>
                <td width="33.3333%"><?= $user_role[0] ?></td>
                <td width="33.3333%"><?= $last_date ?></td>
            </tr>
            <?php
                endforeach;
            ?>
        </tbody>
    </table>
    <?php
}


// retourn la dernière date de connexion d'un utilisateur
function lul_get_user_last_login($user_id)
{
    $last_login = get_user_meta($user_id, 'lul_last_login');
    if (empty($last_login)) {
        return 'jamais';
    } else {
        $the_login_date = strftime('Le %d %B %Y &agrave; %Hh%M', $last_login[0]);
        $time_in_utf8 = iconv(mb_detect_encoding($the_login_date, mb_detect_order(), true), "UTF-8", $the_login_date);
        return $time_in_utf8;
    }
}